package org.zheng.demo;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import org.junit.jupiter.api.Test;
import org.zheng.demo.data.Customer;

import com.fasterxml.jackson.core.exc.StreamReadException;
import com.fasterxml.jackson.databind.DatabindException;
import com.fasterxml.jackson.databind.ObjectMapper;

class JacksonTest {

	private ObjectMapper ob = new ObjectMapper();

	@Test
	void test_readFile_withCustomizedRoot() {
		File jsonFile = new File("src/test/resources/customerWithJsonType.json");

		try {
			org.zheng.demo.type.Customer readCust = ob.readValue(jsonFile, org.zheng.demo.type.Customer.class);

			assertEquals("major", readCust.getCustTag());
			assertEquals("test@test.com", readCust.getEmail());
			assertEquals("Zheng", readCust.getName());
			assertEquals(30, readCust.getId());
			assertEquals(2, readCust.getOrders().size());
			assertEquals("test", readCust.getOrders().get(0).getProductName());
			
			String jsonStr = ob.writerWithDefaultPrettyPrinter().writeValueAsString(readCust);
			System.out.println(jsonStr);


		} catch (IOException e) {
			e.printStackTrace();
		}

	}

	@Test
	void test_readJsonFromFile_via() throws StreamReadException, DatabindException, IOException {

		try (InputStream inputStream = JacksonTest.class.getResourceAsStream("/customer.json")) {
			if (inputStream == null) {
				System.out.println("File not found");
				return;
			}

			Customer cust = ob.readValue(inputStream, Customer.class);

			assertEquals("major", cust.getCustTag());
			assertEquals("test@test.com", cust.getEmail());
			assertEquals("Zheng", cust.getName());
			assertEquals(30, cust.getId());
			assertEquals(2, cust.getOrders().size());
			assertEquals("test", cust.getOrders().get(0).getProductName());

			String jsonStr = ob.writerWithDefaultPrettyPrinter().writeValueAsString(cust);
			System.out.println(jsonStr);

		} catch (IOException e) {
			e.printStackTrace();
		}

	}

}
