package org.zheng.demo;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.junit.jupiter.api.Test;
import org.zheng.demo.data.Customer;
import org.zheng.demo.data.Order;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;

class Jackson_Node_Test {

	@Test
	void test_readJsonFromFile_via_readTree() {
		ObjectMapper ob = new ObjectMapper();
		File jsonFile = new File("src/test/resources/customer.json");
		try {
			JsonNode jsonNodes = ob.readTree(jsonFile);

			String name = jsonNodes.get("name").asText();
			int id = jsonNodes.get("id").asInt();
			Customer cust = new Customer(name, id);

			cust.setCustTag(jsonNodes.get("custTag").asText());
			cust.setEmail(jsonNodes.get("email").asText());

			List<Order> orders = new ArrayList<>();
			cust.setOrders(orders);

			JsonNode ordersNode = jsonNodes.get("orders");
			if (ordersNode.isArray()) {
				for (JsonNode orderNode : ordersNode) {
					JsonNode nameNode = orderNode.get("productName");
					JsonNode quantityNode = orderNode.get("quantity");
					orders.add(new Order(quantityNode.asInt(), nameNode.asText()));
				}
			}

			assertEquals("major", cust.getCustTag());
			assertEquals("test@test.com", cust.getEmail());
			assertEquals("Zheng", cust.getName());
			assertEquals(30, cust.getId());
			assertEquals(2, cust.getOrders().size());
			assertEquals("test", cust.getOrders().get(0).getProductName());

			System.out.println(ob.writerWithDefaultPrettyPrinter().writeValueAsString(cust));
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
