package org.zheng.demo;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.junit.jupiter.api.Test;
import org.zheng.demo.data.Customer;
import org.zheng.demo.data.Order;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;

class Jackson_WrapRootTest {

	private ObjectMapper ob = new ObjectMapper();

	@Test
	void test_readFile_withWrapRoot() {
		File jsonFile = new File("src/test/resources/customerWithWrapRoot.json");

		try {
			Customer readCust = ob.readerFor(Customer.class).with(DeserializationFeature.UNWRAP_ROOT_VALUE)
					.readValue(jsonFile);

			assertEquals("major", readCust.getCustTag());
			assertEquals("test@test.com", readCust.getEmail());
			assertEquals("Zheng", readCust.getName());
			assertEquals(30, readCust.getId());
			assertEquals(2, readCust.getOrders().size());
			assertEquals("test", readCust.getOrders().get(0).getProductName());

		} catch (IOException e) {
			e.printStackTrace();
		}

	}

	@Test
	void test_write_read_withRoot() {
		Customer cust = new Customer("Zheng", 30);
		Order order = new Order();
		cust.setEmail("test@test.com");
		List<Order> orders = new ArrayList<>();
		order.setProductName("test");
		order.setQuantity(10);
		orders.add(order);
		orders.add(order);
		cust.setOrders(orders);

		try {
			String jsonString = ob.enable(SerializationFeature.WRAP_ROOT_VALUE).writeValueAsString(cust);
			System.out.println("Serialized JSON: " + jsonString);

		} catch (JsonProcessingException e) {
			e.printStackTrace();
		}

	}
}
